@@ -43,7 +43,7 @@ my_error (const gchar *format, ...)
 	va_start (args, format);
 	g_print ("Fatal error:\n    ");
 	vsnprintf (buffer, 2048, format, args);
-	g_print (buffer);
+	g_print ("%s", buffer);
 	va_end (args);
 	g_print ("\nAborting ...\n");
 	exit (-1);
